<img width="887" alt="Screenshot 2022-06-10 at 9 29 10 PM" src="https://user-images.githubusercontent.com/90202062/173105881-1dedb62e-256d-4e08-a676-505a26cac94c.png">
create beautiful notes right from the terminal
